/*  DeltaASP: Delta-debugger for answer set solver development.
 *  Copyright (C) 2009  Robert Daniel Brummayer
 *
 *  This file is part of DeltaASP.
 *
 *  DeltaASP is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DeltaASP is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package parser;

import java.util.*;

public class CardinalityElement extends RuleElement {

  public List<Literal> lits;

  public int upper;

  public int lower;

  public boolean upperIsSet;

  public boolean lowerIsSet;

  public CardinalityElement (List<Literal> lits, int lower, int upper, 
                             boolean lowerIsSet, boolean upperIsSet) {
    int size;

    assert (lits != null);
    assert (lits.size() > 0);
    assert (!lowerIsSet || !upperIsSet || upper >= lower);
    size = lits.size();
    this.lits = new Vector<Literal>(size);
    for (Literal lit : lits)
      this.lits.add (lit);
    this.upper = upper;
    this.lower = lower;
    this.upperIsSet = upperIsSet;
    this.lowerIsSet = lowerIsSet;
  }

  public String toString() {
    StringBuilder builder;
    int size;

    assert (this.lits != null);
    assert (this.lits.size() > 0);

    builder = new StringBuilder();
    if (this.lowerIsSet) {
      builder.append (String.valueOf(this.lower));
      builder.append (" ");
    }
    builder.append ("{");
    builder.append (this.lits.get(0));
    size = this.lits.size();
    for (int i = 1; i < size; i++) {
      builder.append(", ");
      builder.append(this.lits.get(i).toString());
    }
    builder.append ("}");
    if (this.upperIsSet) {
      builder.append (" ");
      builder.append (String.valueOf(this.upper));
    }
    return builder.toString();
  }

}

