/*  DeltaASP: Delta-debugger for answer set solver development.
 *  Copyright (C) 2009  Robert Daniel Brummayer
 *
 *  This file is part of DeltaASP.
 *
 *  DeltaASP is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DeltaASP is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package parser;

import java.util.*;

public class Rule {

  public RuleElement head;

  public List<RuleElement> body;

  public Rule (RuleElement head, List<RuleElement> body) {
    assert (!(head == null && body == null));
    assert (body == null || body.size() > 0);
    this.head = head;
    this.body = body;
  }

  public String toString() {
    StringBuilder builder = new StringBuilder();
    int size;
    assert (!(this.head == null && this.body == null));

    if (this.head != null) {
      builder.append (this.head.toString());
      if (this.body != null)
        builder.append (" ");
    }

    if (this.body != null) {
      builder.append (":- ");
      size = this.body.size();
      assert (size > 0);
      builder.append (this.body.get(0).toString());
      for (int i = 1; i < size; i++) {
        builder.append (", ");
        builder.append (this.body.get(i).toString());
      }
    }
    builder.append (".");
    return builder.toString();
  }

}

