/*  DeltaASP: Delta-debugger for answer set solver development.
 *  Copyright (C) 2009  Robert Daniel Brummayer
 *
 *  This file is part of DeltaASP.
 *
 *  DeltaASP is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DeltaASP is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package parser;

import java.util.*;

public class WeightElement extends RuleElement {

  public List<WeightObject> objs;

  public int upper;

  public int lower;

  public boolean upperIsSet;

  public boolean lowerIsSet;

  public WeightElement (List<Literal> lits, List<Integer> weights, 
                        List<Boolean> weightIsSet, int lower, int upper, 
                        boolean lowerIsSet, boolean upperIsSet) {
    int size;

    assert (lits != null);
    assert (lits.size() > 0);
    assert (weights != null);
    assert (weights.size() > 0);
    assert (weightIsSet != null);
    assert (weightIsSet.size() > 0);
    assert (lits.size() == weights.size());
    assert (weights.size() == weightIsSet.size());
    assert (!lowerIsSet || !upperIsSet || upper >= lower);
    size = lits.size();
    this.objs = new Vector<WeightObject>(size);
    for (int i = 0; i < size; i++)
      this.objs.add (new WeightObject (lits.get(i), weights.get(i).intValue(), 
                                       weightIsSet.get(i) == Boolean.TRUE));
    this.upper = upper;
    this.lower = lower;
    this.upperIsSet = upperIsSet;
    this.lowerIsSet = lowerIsSet;
  }

  public String toString() {
    StringBuilder builder;
    int size;
    WeightObject obj;

    assert (this.objs != null);
    assert (this.objs.size() > 0);
    assert (!this.lowerIsSet || !this.upperIsSet || this.upper >= this.lower);

    builder = new StringBuilder();
    if (this.lowerIsSet) {
      builder.append (String.valueOf(this.lower));
      builder.append (" ");
    }
    builder.append ("[");
    obj = this.objs.get(0);
    builder.append (obj.lit.toString());
    if (obj.isSet) {
      builder.append (" = ");
      builder.append (String.valueOf(obj.weight));
    }
    size = this.objs.size();
    for (int i = 1; i < size; i++) {
      builder.append(", ");
      obj = this.objs.get(i);
      builder.append(obj.lit.toString());
      if (obj.isSet) {
        builder.append (" = ");
        builder.append (String.valueOf(obj.weight));
      }
    }
    builder.append ("]");
    if (this.upperIsSet) {
      builder.append (" ");
      builder.append (String.valueOf(this.upper));
    }
    return builder.toString();
  }

}

